@@ -4,6 +4,9 @@ from pyutil.assertutil import precondition, _assert
 
 from collections import deque
 
+# Note: when changing this class, you should un-comment all the lines that say
+# "assert self._assert_invariants()".
+
 class StringChain(object):
     def __init__(self):
         self.d = deque()
@@ -13,7 +16,7 @@ class StringChain(object):
 
     def append(self, s):
         """ Add s to the end of the chain. """
-        assert self._assert_invariants()
+        #assert self._assert_invariants()
         if not s:
             return
 
@@ -24,7 +27,7 @@ class StringChain(object):
 
         self.d.append(s)
         self.len += len(s)
-        assert self._assert_invariants()
+        #assert self._assert_invariants()
 
     def __str__(self):
         """ Return the entire contents of this chain as a single
@@ -42,7 +45,7 @@ class StringChain(object):
         """ Remove some of the leading bytes of the chain and return them as a
         new StringChain object. (Use str() on it if you want the bytes in a
         string, or call popleft() instead of popleft_new_stringchain().) """
-        assert self._assert_invariants()
+        #assert self._assert_invariants()
         if not bytes or not self.d:
             return self.__class__()
 
@@ -73,16 +76,16 @@ class StringChain(object):
             self.ignored = 0
 
         # Either you got exactly how many you asked for, or you drained self entirely and you asked for more than you got.
-        assert (n.len == bytes) or ((not self.d) and (bytes > self.len)), (n.len, bytes, len(self.d))
+        #assert (n.len == bytes) or ((not self.d) and (bytes > self.len)), (n.len, bytes, len(self.d))
 
-        assert self._assert_invariants()
-        assert n._assert_invariants()
+        #assert self._assert_invariants()
+        #assert n._assert_invariants()
         return n
 
     def popleft(self, bytes):
         """ Remove some of the leading bytes of the chain and return them as a
         string. """
-        assert self._assert_invariants()
+        #assert self._assert_invariants()
         if not bytes or not self.d:
             return ''
 
@@ -117,19 +120,19 @@ class StringChain(object):
         resstr = ''.join(resstrs)
 
         # Either you got exactly how many you asked for, or you drained self entirely and you asked for more than you got.
-        assert (len(resstr) == bytes) or ((not self.d) and (bytes > self.len)), (len(resstr), bytes, len(self.d), overrun)
+        #assert (len(resstr) == bytes) or ((not self.d) and (bytes > self.len)), (len(resstr), bytes, len(self.d), overrun)
 
-        assert self._assert_invariants()
+        #assert self._assert_invariants()
 
         return resstr
 
     def __len__(self):
-        assert self._assert_invariants()
+        #assert self._assert_invariants()
         return self.len
 
     def trim(self, bytes):
         """ Trim off some of the leading bytes. """
-        assert self._assert_invariants()
+        #assert self._assert_invariants()
         self.ignored += bytes
         self.len -= bytes
         while self.d and self.ignored >= len(self.d[0]):
@@ -139,13 +142,15 @@ class StringChain(object):
             self.len = 0
         if not self.d:
             self.ignored = 0
-        assert self._assert_invariants()
+        #assert self._assert_invariants()
 
     def copy(self):
         n = self.__class__()
         n.ignored = self.ignored
+        n.tailignored = self.tailignored
         n.len = self.len
         n.d = copy.copy(self.d)
+        #assert n._assert_invariants()
         return n
 
     def _assert_invariants(self):
@@ -162,7 +167,7 @@ class StringChain(object):
         """ Concatenate all of the strings into one string and make that string
         be the only element of the chain. (Obviously this requires copying all
         of the bytes, so don't do this unless you need to.) """
-        assert self._assert_invariants()
+        #assert self._assert_invariants()
         # First trim off any leading ignored bytes.
         if self.ignored:
             self.d[0] = self.d[0][self.ignored:]
@@ -175,4 +180,4 @@ class StringChain(object):
             newstr = ''.join(self.d)
             self.d.clear()
             self.d.append(newstr)
-        assert self._assert_invariants()
+        #assert self._assert_invariants()
