@@ -1,5 +1,6 @@
 import unittest
 from stringchain.stringchain import StringChain as BufClass
+# from stringchain.bench.bench import Dequey as BufClass
 # from stringchain.bench.bench import Stringy as BufClass
 # from stringchain.bench.bench import StringIOy as BufClass
 # from stringchain.bench.bench import SimplerStringChain as BufClass
@@ -150,3 +151,11 @@ class T(unittest.TestCase):
         s = c.popleft(4) # We just silently pop them all.
         self.failUnlessEqual(s, "abc")
         self.failUnlessEqual(str(c.copy()), "")
+
+    def test_tailignored(self):
+        c1 = BufClass()
+        c1.append("abcde")
+        c2 = c1.popleft_new_stringchain(2)
+        assert str(c2.copy()) == "ab", (str(c2.copy()),)
+        c2.append("f")
+        self.failUnlessEqual(str(c2.copy()), "abf")
